<?php
// $Id: dspam_conf.php,v 1.5 2004/04/06 20:59:21 perlstalker Exp $

// Path to dspam's userdir
$dspam_userdir = '/var/mail/virtual/dspam';

// Are users required to opt-in?
//  1 => users opt-in; 0 => users opt-out
$enable_optin = 1;

// Enable homedir dot-files
// Note: The user's homedir needs to be writable by the web server.
// Note: homedir dot-files are not supported yet.
$enable_homedir_dotfiles = 0;

// Ask to clean out spam folder on dspam opt-in if enable_optin is on.
$clean_spam = 1;

// If set, show long instructions for using dspam.
$show_instructions = 0;

$show_primer_link = 1;

// If set, a warning will be displayed in the dspam section informing users
// that SpamAssassin is disabled when dspam is used. This doesn't hide the
// SpamAssassin sections.
$show_SAdisabled_warning = 1;

?>