<?php
// $Id: policyd_conf-dist.php,v 1.2 2006/11/19 03:01:09 perlstalker Exp $

// DSN for database
// Do not include <> in your actual values
$policyd_dsn = 'mysql://<user>:<pass>@<host>/<db>';

// Priority
// This should be higher than the global greylist policy.
// See http://policyd.sourceforge.net/readme.html for a detailed
// description.
$policyd_grey_priority = 50;

// If set to 0, users will need to opt-in.
// If set to 1, users will need to opt-out.
// Be sure to set your global policy (in policyd) correctly
$policyd_grey_default = 0;

// If your users can login with just their username, for example
// 'joe' instead of 'joe@example.com', please use the vlogin plugin
// or set $default_domain is sasql_conf.php to append the correct
// domain to the user name.