<?php
// $Id: sa_abooksync.inc.php,v 1.3 2004/03/19 22:06:41 perlstalker Exp $

if (!defined('SM_PATH')) { define('SM_PATH' , '../../'); }

include_once(SM_PATH.'plugins/sasql/sasql_api.php');

global $username;

sqgetGlobalVar('do_sync', $do_sync, SQ_FORM);
if ($do_sync) {
  sasql_syncABookWithWList ($username);
}

?>

<table width="100%" border="0" cellpadding="1" cellspacing="1">
 <tr>
  <td align='center' bgcolor="<?php echo $color[4]; ?>">
   <b><?php echo _("Allow Senders from Address Book") ?></b>
  </td>
 </tr>
 <tr>
  <td align='center' bgcolor="<?php echo $color[4]; ?>">
   <form action='sasql_options.php' method='Post'>
    <input type='submit' name='do_sync' value='<?php echo _("Allow"); ?>' />
<?php echo _("Allow all address in the address book."); ?>
   </form>
  </td>
 </tr>
</table>